=======================
chaostoolkit-storeevent
=======================


.. image:: https://img.shields.io/pypi/v/chaostoolkit_storeevent.svg
        :target: https://pypi.python.org/pypi/chaostoolkit_storeevent

.. image:: https://img.shields.io/travis/grubert65/chaostoolkit_storeevent.svg
        :target: https://travis-ci.org/grubert65/chaostoolkit_storeevent

.. image:: https://readthedocs.org/projects/chaostoolkit-storeevent/badge/?version=latest
        :target: https://chaostoolkit-storeevent.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A chaostoolkit control to store events on different data stores/monitoring platfoms


* Free software: BSD license
* Documentation: https://chaostoolkit-storeevent.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
